@echo OFF
REM
REM Licensed Materials-Property of IBM
REM (C)Copyright IBM Corp 2008
REM All rights reserved
REM US Government Users Restricted Rights
REM Use, duplication, or disclosure restricted
REM by GSA ADP Schedule Contract with IBM Corp
REM
REM  arg1 -  log  -   log file to be used by this script 
REM  arg2 -  instance  -  instance name (for example db2inst2) 
REM  arg3 -  dbname  -  database name
REM  arg4 -  dbuserid  - database instance owner
REM  arg5 -  dbpassword  - database password
REM  arg6 -  dbport - database port where the instance is listening. 
REM  arg7 -  DRIVELETTER - drive letter
REM 
REM   Note:  The batch file
REM 	        must be run on the same machine where DB2 server is installed.
REM 		uoes not do parameter validation
REM 	  	will fail if the user specifies a wrong dbuserid or password
REM 	   will drop the database instance and database it created 
REM 	   will not drop database or instance created by ezinstall.
REM 		uses the database name as it alias

REM ----------------------------------------------------------------------------

setlocal

%~d0
cd %~p0

set LOG=%~s1
REM Set DB2INSTANCE environment variable 
set DB_INST=%2
set DB_NAME=%3
set DB_USERID=%4
set DB_PASSWORD=%5
set DBPORTB=%6
set /a DBPORTE=%6+3
set RC=0
SET DB2INSTANCE=%DB_INST%
SET DBARCHDIR=%7/sklmdbarchive
SET OSDIR=%7\sklmdbarchive


REM Logging the header information in dbconfig.log file
echo ---------------------------------------------------------------------------------------------- >> "%LOG%" 
echo Started executing dbtklmcr.bat >> "%LOG%" 
echo ---------------------------------------------------------------------------------------------- >> "%LOG%" 

REM directory where scripts and response files have been written
set CURRENT_DIR=.
set IS_CONNECTED=0
set CREATE_DB=0
set DB_CREATED=0
set INST_CREATED=0
SET DIR_CREATED=0
set SVCE_NAME=DB2_%DB_INST%

IF NOT EXIST %OSDIR%\nul goto CREATE_DIR 

echo %OSDIR% exists. DB2 will use this directory for saving DB2 non active transactional logs. >> "%LOG%
goto CREATE_INST

:CREATE_DIR
MKDIR %OSDIR%
set RC=%ERRORLEVEL%
if %RC%==0 set DIR_CREATED=1
if not %RC%==0 goto ERROR
echo %OSDIR% directory created. DB2 will use this directory for saving DB2 non active transactional logs. >> "%LOG%
goto CREATE_INST



REM CHECK FOR THE INSTANCE
REM db2ilist | FINDSTR /I /L /X %DB2_INST%   
REM echo DB2 Instance %DB_INST% exists >> %LOG%
REM if %RC%==0 goto CHECKDB



:CREATE_INST
REM Create User
call createUser.bat %DB_USERID% %DB_PASSWORD% db2admns
REM Create an instance
echo db2icrt %DB_INST%  -s wse -u:%DB_USERID%,**** >> "%LOG%"
REM db2icrt %DB_INST%  -s wse -u:%DB_USERID%,%DB_PASSWORD% -r:%DBPORTB%,%DBPORTE%
db2icrt %DB_INST%  -s wse -u:%DB_USERID%,%DB_PASSWORD% 
set RC=%ERRORLEVEL% 
if NOT %RC%==0 goto ERROR
set INST_CREATED=1


REM Create DB
:CREATE_DB
echo "db2 start database manager" >> "%LOG%"
db2 start database manager
echo "db2 create database %DB_NAME% using codeset UTF-8 territory US" >> "%LOG%"
db2 -l "%LOG%" "create database %DB_NAME% using codeset UTF-8 territory US"
set RC=%ERRORLEVEL%
if %RC%==0 set DB_CREATED=1
if not %RC%==0 goto ERROR

REM CREATE TABLES 
:RUNDDL
set RC=0
REM Database is created, now connect to database
echo "db2 start database manager" >> "%LOG%"
db2 start database manager
echo "db2 connect to %DB_NAME% USER %DB_USERID% USING *****" >> "%LOG%" 
db2 -l "%LOG%" "connect to %DB_NAME% USER %DB_USERID% USING '%DB_PASSWORD%'"
set RC=%ERRORLEVEL%
if %RC% LSS 0 goto ERROR
if %RC% LSS 3 set RC=0 
if not %RC%==0 goto ERROR
set IS_CONNECTED=1

REM Create database objects including buffer pools, table spaces, XML Schema tables, table indices & metadata.
echo "db2 -s -t -f tklmsql.db2" >> "%LOG%"
db2 -l "%LOG%" -s -t -f tklmsql.db2"
set RC=%ERRORLEVEL%
if %RC% LSS 0 goto ERROR
if %RC% LSS 3 set RC=0 
if not %RC%==0 goto ERROR

echo "db2 update db cfg for %DB_NAME% using logsecond 25" >> %LOG%
db2 update db cfg for  %DB_NAME%  using logsecond 25"
set RC=%ERRORLEVEL%
if %RC% LSS 0 goto ERROR
if %RC% LSS 3 set RC=0 
if not %RC%==0 goto ERROR

echo "db2 update db cfg for %DB_NAME% using logfilsiz 10000" >> %LOG%
db2 update db cfg for  %DB_NAME%  using logfilsiz 10000
set RC=%ERRORLEVEL%
if %RC% LSS 0 goto ERROR
if %RC% LSS 3 set RC=0 
if not %RC%==0 goto ERROR


REM Disconnect from database, no need to check for error code
if %IS_CONNECTED%==1 db2 -l "%LOG%" "connect reset"

REM we have to update the SVCENAME
echo "db2 update dbm cfg using SVCENAME %SVCE_NAME%" >> %LOG%
db2 update dbm cfg using SVCENAME %SVCE_NAME% 
set RC=%ERRORLEVEL%
if %RC% LSS 0 goto ERROR
if %RC% LSS 3 set RC=0 
if not %RC%==0 goto ERROR

echo "db2 update dbm cfg using HEALTH_MON OFF" >> %LOG%
db2 update dbm cfg using HEALTH_MON OFF 
set RC=%ERRORLEVEL%
if %RC% LSS 0 goto ERROR
if %RC% LSS 3 set RC=0 
if not %RC%==0 goto ERROR

echo "db2 update db cfg for %DB_NAME% using APPLHEAPSZ 2048" >> %LOG%
db2 update db cfg for %DB_NAME% using APPLHEAPSZ 2048 
set RC=%ERRORLEVEL%
if %RC% LSS 0 goto ERROR
if %RC% LSS 3 set RC=0 
if not %RC%==0 goto ERROR

echo "db2 update db cfg for %DB_NAME% using LOGARCHMETH1 DISK:%DBARCHDIR%" >> %LOG%
db2 update db cfg for %DB_NAME% using LOGARCHMETH1 DISK:%DBARCHDIR% >> %LOG%
set RC=%ERRORLEVEL%
if %RC% LSS 0 goto ERROR
if %RC% LSS 3 set RC=0 
if not %RC%==0 goto ERROR



echo db2set DB2COMM=TCPIP >> %LOG%
db2set DB2COMM=TCPIP
echo db2set DB2_REDUCED_OPTIMIZATION=ZZJN OFF >> %LOG%
db2set DB2_REDUCED_OPTIMIZATION="ZZJN OFF"
echo "db2 stop database manager force" >> "%LOG%"
db2 stop database manager force
echo "db2stop force" >> "%LOG%"
db2stop force
REM echo "db2 start database manager" >> "%LOG%"
REM db2 start database manager
echo "db2start" >> "%LOG%"
db2start
echo "db2 backup db %DB_NAME% to nul" >> "%LOG%"
db2 backup db %DB_NAME% to nul >> "%LOG%"
REM disconnect from db if connected
goto END



REM goto END

:ERROR
if %DB_CREATED%==1 goto DROP_DB
if %INST_CREATED%==1 goto DROP_INST
if %IS_CONNECTED%==1 goto DISCONNECT_DB

goto END


:DROP_DB
echo db2 connect reset >> "%LOG%"
if %IS_CONNECTED%==1 db2 -l "%LOG%" "connect reset"
set IS_CONNECTED=0
REM Drop the database %DB_NAME%
echo "db2 drop database %DB_NAME%" >> "%LOG%"
db2 -l "%LOG%" "drop database %DB_NAME%"
if %INST_CREATED%==1 goto DROP_INST
goto END

:DROP_INST
echo "db2 stop database manager force" >> "%LOG%"
db2 stop database manager force
echo db2idrop -f %DB_INST% >> "%LOG%"
db2idrop -f %DB_INST%
if %IS_CONNECTED%==1 db2 -l "%LOG%" "connect reset"
set IS_CONNECTED=0
if %DIR_CREATED%==1 goto DROP_DIR

goto END

:DROP_DIR
DEL /F /S /Q %OSDIR%
RMDIR %OSDIR%

goto END

:DISCONNECT_DB
REM Disconnect DB
db2 -l "%LOG%" "connect reset"
set IS_CONNECTED=0
goto END



:PRINT_USAGE
echo "Usage: dbtklmcr.bat logfile dbinstance dbname dbusername dbpassword dbport dbdrive" >> "%LOG% 
set RC=1
goto END

:END
if %RC%==0 echo Return=%RC% >> "%LOG%"
if %RC% neq 0 echo Return %RC% >> "%LOG%"

echo ---------------------------------------------------------------------------------------------- >> "%LOG%" 
exit %RC%
endlocal
