@rem Licensed Materials-Property of IBM
@rem (C)Copyright IBM Corp 2009
@rem All rights reserved
@rem US Government Users Restricted Rights
@rem Use, duplication, or disclosure restricted
@rem by GSA ADP Schedule Contract with IBM Corp
@rem arg0 - TKLM_HOME
@rem arg1 - DB2 LOCATION
@rem arg2 - DB2 INSTANCE
@rem arg3 - ACTION (0 - stop, 1 - start, 2 - restart)
@echo off
goto :MAIN

:ClearErrorLevel
    
    @rem Input   : reqires the following environment variables
    @rem Output  : sets the following environment variables 
    @rem Process : Following tasks are performed during pre-migration 
    @rem Clear ERRORLEVEL so || and && operators work correctly...
    
    ( dir %COMPSPEC% 2>&1 ) >NUL

@rem End ClearErrorLevel
goto :EOF

:initEnv

    @rem Input   : reqires the following environment variables
    @rem Output  : sets the following environment variables 
    @rem Process : Initialize the environment variables

    set CLEANUP=1
    set ERROR=

    
    set DB2LOC=0
    set DB2_INSTANCE=
    set CHGLOG_DEFINED=
    set START_STOP_LOG=


@rem End initEnv
goto :EOF

:ParseCmdLine

    @rem Input   : reqires the following environment variables
    @rem           1) %*
    @rem Output  : sets the following environment variables 
    @rem           1) ERROR
    @rem Process : Following tasks are performed during pre-migration 
    set TKLM_HOME=%~s1
    set DB2LOC=%~s2
    set DB2_INSTANCE=%3
    set ACTION=%4


@rem End ParseCmdLine
goto :EOF

:USAGE
    exit /B %ERROR%
@rem End USAGE
goto :EOF


:prepare_db2_start_dbm

    set DB2INSTANCE=%DB2_INSTANCE%

    @rem start the database manager
   
    echo "%DB2LOC%"\BIN\db2cmd -c -w -i db2 -tv start database manager>>%START_STOP_LOG%
    call "%DB2LOC%"\BIN\db2cmd -c -w -i db2 -tv start database manager>>%START_STOP_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %START_STOP_LOG%
    IF (%RC%) GTR  (4) (
       SET ERROR=20
    )

goto :EOF

:prepare_db2_stop_dbm

    set DB2INSTANCE=%DB2_INSTANCE%

    @rem  terminate the current connection
    echo "%DB2LOC%"\BIN\db2cmd -c -w -i db2 -tv terminate>>%START_STOP_LOG%
    call "%DB2LOC%"\BIN\db2cmd -c -w -i db2 -tv terminate>>%START_STOP_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %START_STOP_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=10
        goto :EOF
    )

    @rem  terminate all applications connected to the database
    echo "%DB2LOC%"\BIN\db2cmd -c -w -i db2 -tv force application all>>%START_STOP_LOG%
    call "%DB2LOC%"\BIN\db2cmd -c -w -i db2 -tv force application all>>%START_STOP_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %START_STOP_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=11
        goto :EOF
    )

    @rem stop the database manager
    echo "%DB2LOC%"\BIN\db2cmd -c -w -i db2stop force >>%START_STOP_LOG%
    call "%DB2LOC%"\BIN\db2cmd -c -w -i db2stop force >>%START_STOP_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %START_STOP_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=12
        goto :EOF
    )

goto :EOF

:prepare_db2_restart_dbm

    call :prepare_db2_stop_dbm

    call :prepare_db2_start_dbm

goto :EOF




:MAIN


    call :initEnv

    call :ParseCmdLine %*
    if NOT DEFINED DB2LOC (
        exit /B 2
    )
    set START_STOP_LOG="%TKLM_HOME%\migration\migrate_db2server.log"


    @rem get the DB2 instance name and DB2 database name from the TDS 6.2
    @rem instance configuration file

    if NOT DEFINED TKLM_HOME (
        exit /B 1
    )
    if (%ACTION%) == (0) (
       call :prepare_db2_stop_dbm
	
    )
    if (%ACTION%) == (1) (
       call :prepare_db2_start_dbm
    )

    if defined ERROR (
	exit /B %ERROR%
    )
   
    echo "Return=0"
    exit /B 0

@rem End MAIN
:end
